==> dde-shell_1.99.6.tar.xz: BUILD/panels/dock/dcc-dock-plugin/translations/dock_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>PluginArea</name>
    <message>
        <source>Plugin Area</source>
        <translation>Bővítmény terület</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Válassza ki, hogy mely ikonok jelenjenek meg a dokkolóban</translation>
    </message>
</context>
<context>
    <name>dock</name>
    <message>
        <source>Desktop and taskbar</source>
        <translation>Asztal és Tálca</translation>
    </message>
    <message>
        <source>Set the display and size of icons on the desktop</source>
        <translation>Állítsa be az asztalon lévő ikonok megjelenítését és méretét</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dock</source>
        <translation>Dokkoló</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Fashion</source>
        <translation>Stílusos mód</translation>
    </message>
    <message>
        <source>Efficient-left</source>
        <translation>Hatékony mód - bal</translation>
    </message>
    <message>
        <source>Efficient-center</source>
        <translation>Hatékony mód - közép</translation>
    </message>
    <message>
        <source>Dock size</source>
        <translation>Dokkoló mérete</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <source>Position on the screen</source>
        <translation>Képernyőn való pozíció</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Megjelenítve tartás</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Maradjon rejtett</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Többképernyős mód</translation>
    </message>
    <message>
        <source>Set the position of the taskbar on the screen</source>
        <translation>Állítsa be a tálca helyzetét a képernyőn</translation>
    </message>
    <message>
        <source>Only on main</source>
        <translation>Megjelenítés csak a Főképernyőn</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Azon a képernyőn ahol a kurzor található</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Bővítmény terület</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Válassza ki, hogy mely ikonok jelenjenek meg a dokkolóban</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.7.tar.xz: BUILD/panels/dock/dcc-dock-plugin/translations/dock_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>PluginArea</name>
    <message>
        <source>Plugin Area</source>
        <translation>Bővítmény terület</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Válassza ki, hogy mely ikonok jelenjenek meg a dokkolóban</translation>
    </message>
</context>
<context>
    <name>dock</name>
    <message>
        <source>Desktop and taskbar</source>
        <translation>Asztal és Tálca</translation>
    </message>
    <message>
        <source>Set the display and size of icons on the desktop</source>
        <translation>Állítsa be az asztalon lévő ikonok megjelenítését és méretét</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dock</source>
        <translation>Dokkoló</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Mód</translation>
    </message>
    <message>
        <source>Dock size</source>
        <translation>Dokkoló mérete</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Kicsi</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Nagy</translation>
    </message>
    <message>
        <source>Position on the screen</source>
        <translation>Képernyőn való pozíció</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Jobb</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Állapot</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Megjelenítve tartás</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Maradjon rejtett</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Intelligens elrejtés</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Többképernyős mód</translation>
    </message>
    <message>
        <source>Set the position of the taskbar on the screen</source>
        <translation>Állítsa be a tálca helyzetét a képernyőn</translation>
    </message>
    <message>
        <source>Only on main</source>
        <translation>Megjelenítés csak a Főképernyőn</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Azon a képernyőn ahol a kurzor található</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Bővítmény terület</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Válassza ki, hogy mely ikonok jelenjenek meg a dokkolóban</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
